import java.io.*;
import java.net.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.colorchooser.*;

/** Colour chooser for Mike's Ambient Device.
 * This class wraps a JColorChooser to provide a simple selector for setting
 * the ambient device to any given colour.
 *
 * The code is adapted from the Java Tutorial at:
 *
 *  http://java.sun.com/docs/books/tutorial/uiswing/components/colorchooser.html
 *
 */
public class ColourChooser extends JPanel implements ChangeListener
{
    protected JColorChooser  tcc;
    private   DatagramSocket sock;
    private   InetAddress    device;

    public ColourChooser()
    {
        super(new BorderLayout());

        tcc = new JColorChooser();
        tcc.getSelectionModel().addChangeListener(this);
        tcc.setBorder(BorderFactory.createTitledBorder("Choose Colour"));
        add(tcc, BorderLayout.CENTER);

        try
        {
            sock = new DatagramSocket(8888);
        }
        catch(SocketException se)
        {
            throw new RuntimeException(se);
        }
    }

    public void stateChanged(ChangeEvent e)
    {
        Color c = tcc.getColor();

        if(device == null)
        {
            try
            {
                device = InetAddress.getByName("LIGHTBULB");
                System.out.println("Device is at: " + device);
            }
            catch(UnknownHostException uhe)
            {
                System.out.println("Lookup failed");
            }
        }

        if(device != null)
        {
            byte p[] = new byte[6];

			p[0] = 5; 		   /* Count of command bytes */
            p[1] = 0; 	       /* Set colour, no delay */
            p[2] = (byte)c.getRed();
            p[3] = (byte)c.getGreen();
            p[4] = (byte)c.getBlue();
            p[5] = (byte)0xf0; /* Stop */

            try
            {
                sock.send(new DatagramPacket(p, p.length, device, 8888));
            }
            catch(IOException ioe)
            {
            }
        }

        System.out.println(c);
    }

    /**
     * Create the GUI and show it.  For thread safety,
     * this method should be invoked from the
     * event-dispatching thread.
     */
    private static void createAndShowGUI() {

        /* Create and set up the window */
        JFrame frame = new JFrame("Colour Chooser");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        /* Create and set up the content pane */
        JComponent newContentPane = new ColourChooser();
        newContentPane.setOpaque(true);
        frame.setContentPane(newContentPane);

        /* Display the window */
        frame.pack();
        frame.setVisible(true);
    }

    public static void main(String[] args) {

        javax.swing.SwingUtilities.invokeLater(
            new Runnable()
            {
                public void run()
                {
                    createAndShowGUI();
                }
            }
        );
    }
}

/* END OF FILE */
